==> libsbml-3.3.2-src.zip: libsbml-3.3.2/src/bindings/java/test/org/sbml/libsbml/test/sbml/TestListOf.java <==
/*
 *
 * @file    TestListOf.java
 * @brief   ListOf unit tests
 *
 * @author  Akiya Jouraku (Java conversion)
 * @author  Ben Bornstein 
 *
 * $Id: TestListOf.java 8704 2009-01-04 02:26:05Z mhucka $
 * $HeadURL: https://sbml.svn.sourceforge.net/svnroot/sbml/trunk/libsbml/src/bindings/java/test/org/sbml/libsbml/test/sbml/TestListOf.java $
 *
 * This test file was converted from src/sbml/test/TestListOf.c
 * with the help of conversion sciprt (ctest_converter.pl).
 *
 *<!---------------------------------------------------------------------------
 * This file is part of libSBML.  Please visit http://sbml.org for more
 * information about SBML, and the latest version of libSBML.
 *
 * Copyright 2005-2008 California Institute of Technology.
 * Copyright 2002-2005 California Institute of Technology and
 *                     Japan Science and Technology Corporation.
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation.  A copy of the license agreement is provided
 * in the file named "LICENSE.txt" included with this software distribution
 * and also available online as http://sbml.org/software/libsbml/license.html
 *--------------------------------------------------------------------------->*/


package org.sbml.libsbml.test.sbml;

import org.sbml.libsbml.*;

import java.io.File;
import java.lang.AssertionError;

public class TestListOf {

  static void assertTrue(boolean condition) throws AssertionError
  {
    if (condition == true)
    {
      return;
    }
    throw new AssertionError();
  }

  static void assertEquals(Object a, Object b) throws AssertionError
  {
    if ( (a == null) && (b == null) )
    {
      return;
    }
    else if (a.equals(b))
    {
      return;
    }

    throw new AssertionError();
  }

  static void assertNotEquals(Object a, Object b) throws AssertionError
  {
    if ( (a == null) && (b == null) )
    {
      throw new AssertionError();
    }
    else if (a.equals(b))
    {
      throw new AssertionError();
    }
  }

  static void assertEquals(boolean a, boolean b) throws AssertionError
  {
    if ( a == b )
    {
      return;
    }
    throw new AssertionError();
  }

  static void assertNotEquals(boolean a, boolean b) throws AssertionError
  {
    if ( a != b )
    {
      return;
    }
    throw new AssertionError();
  }

  static void assertEquals(int a, int b) throws AssertionError
  {
    if ( a == b )
    {
      return;
    }
    throw new AssertionError();
  }

  static void assertNotEquals(int a, int b) throws AssertionError
  {
    if ( a != b )
    {
      return;
    }
    throw new AssertionError();
  }

  public void test_ListOf_clear()
  {
    ListOf lo = new  ListOf();
    SBase sp = new  Species();
    lo.append(sp);
    lo.append(sp);
    lo.append(sp);
    lo.append(sp);
    lo.append(sp);
    assertTrue( lo.size() == 5 );
    lo.clear(true);
    assertTrue( lo.size() == 0 );
    lo.append(sp);
    lo.append(sp);
    lo.append(sp);
    lo.append(sp);
    lo.appendAndOwn(sp);
    assertTrue( lo.size() == 5 );
    lo.get(0);
    lo.get(1);
    lo.get(2);
    lo.get(3);
    lo.get(4);
    lo.clear(false);
    assertTrue( lo.size() == 0 );
    lo = null;
  }

  public void test_ListOf_create()
  {
    ListOf lo = new  ListOf();
    assertTrue( lo.getTypeCode() == libsbml.SBML_LIST_OF );
    assertTrue( lo.getNotes() == null );
    assertTrue( lo.getAnnotation() == null );
    assertTrue( lo.getMetaId().equals("") == true );
    assertTrue( lo.size() == 0 );
    lo = null;
  }

  public void test_ListOf_free_NULL()
  {
  }

  public void test_ListOf_remove()
  {
    ListOf lo = new  ListOf();
    SBase sp = new  Species();
    assertTrue( lo.size() == 0 );
    lo.append(sp);
    lo.append(sp);
    lo.append(sp);
    lo.append(sp);
    lo.append(sp);
    assertTrue( lo.size() == 5 );
    lo.remove(0);
    lo.remove(0);
    lo.remove(0);
    lo.remove(0);
    lo.remove(0);
    assertTrue( lo.size() == 0 );
    lo.append(sp);
    lo.append(sp);
    lo.append(sp);
    lo.append(sp);
    lo.appendAndOwn(sp);
    assertTrue( lo.size() == 5 );
    lo = null;
  }

  /**
   * Loads the SWIG-generated libSBML Java module when this class is
   * loaded, or reports a sensible diagnostic message about why it failed.
   */
  static
  {
    String varname;
    String shlibname;

    if (System.getProperty("mrj.version") != null)
    {
      varname = "DYLD_LIBRARY_PATH";    // We're on a Mac.
      shlibname = "libsbmlj.jnilib and/or libsbml.dylib";
    }
    else
    {
      varname = "LD_LIBRARY_PATH";      // We're not on a Mac.
      shlibname = "libsbmlj.so and/or libsbml.so";
    }

    try
    {
      System.loadLibrary("sbmlj");
      // For extra safety, check that the jar file is in the classpath.
      Class.forName("org.sbml.libsbml.libsbml");
    }
    catch (SecurityException e)
    {
      e.printStackTrace();
      System.err.println("Could not load the libSBML library files due to a"+
                         " security exception.\n");
      System.exit(1);
    }
    catch (UnsatisfiedLinkError e)
    {
      e.printStackTrace();
      System.err.println("Error: could not link with the libSBML library files."+
                         " It is likely\nyour " + varname +
                         " environment variable does not include the directories\n"+
                         "containing the " + shlibname + " library files.\n");
      System.exit(1);
    }
    catch (ClassNotFoundException e)
    {
      e.printStackTrace();
      System.err.println("Error: unable to load the file libsbmlj.jar."+
                         " It is likely\nyour -classpath option and CLASSPATH" +
                         " environment variable\n"+
                         "do not include the path to libsbmlj.jar.\n");
      System.exit(1);
    }
  }
}

==> libsbml-4.0.0-src.zip: libsbml-4.0.0/src/bindings/java/test/org/sbml/libsbml/test/sbml/TestListOf.java <==
/*
 *
 * @file    TestListOf.java
 * @brief   ListOf unit tests
 *
 * @author  Akiya Jouraku (Java conversion)
 * @author  Ben Bornstein 
 *
 * $Id: TestListOf.java 10068 2009-08-21 18:54:20Z ajouraku $
 * $HeadURL: https://sbml.svn.sourceforge.net/svnroot/sbml/branches/libsbml-4/src/bindings/java/test/org/sbml/libsbml/test/sbml/TestListOf.java $
 *
 * This test file was converted from src/sbml/test/TestListOf.c
 * with the help of conversion sciprt (ctest_converter.pl).
 *
 *<!---------------------------------------------------------------------------
 * This file is part of libSBML.  Please visit http://sbml.org for more
 * information about SBML, and the latest version of libSBML.
 *
 * Copyright 2005-2009 California Institute of Technology.
 * Copyright 2002-2005 California Institute of Technology and
 *                     Japan Science and Technology Corporation.
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation.  A copy of the license agreement is provided
 * in the file named "LICENSE.txt" included with this software distribution
 * and also available online as http://sbml.org/software/libsbml/license.html
 *--------------------------------------------------------------------------->*/


package org.sbml.libsbml.test.sbml;

import org.sbml.libsbml.*;

import java.io.File;
import java.lang.AssertionError;

public class TestListOf {

  static void assertTrue(boolean condition) throws AssertionError
  {
    if (condition == true)
    {
      return;
    }
    throw new AssertionError();
  }

  static void assertEquals(Object a, Object b) throws AssertionError
  {
    if ( (a == null) && (b == null) )
    {
      return;
    }
    else if ( (a == null) || (b == null) )
    {
      throw new AssertionError();
    }
    else if (a.equals(b))
    {
      return;
    }

    throw new AssertionError();
  }

  static void assertNotEquals(Object a, Object b) throws AssertionError
  {
    if ( (a == null) && (b == null) )
    {
      throw new AssertionError();
    }
    else if ( (a == null) || (b == null) )
    {
      return;
    }
    else if (a.equals(b))
    {
      throw new AssertionError();
    }
  }

  static void assertEquals(boolean a, boolean b) throws AssertionError
  {
    if ( a == b )
    {
      return;
    }
    throw new AssertionError();
  }

  static void assertNotEquals(boolean a, boolean b) throws AssertionError
  {
    if ( a != b )
    {
      return;
    }
    throw new AssertionError();
  }

  static void assertEquals(int a, int b) throws AssertionError
  {
    if ( a == b )
    {
      return;
    }
    throw new AssertionError();
  }

  static void assertNotEquals(int a, int b) throws AssertionError
  {
    if ( a != b )
    {
      return;
    }
    throw new AssertionError();
  }

  public void test_ListOf_clear()
  {
    ListOf lo = new  ListOf();
    SBase sp = new  Species(2,4);
    lo.append(sp);
    lo.append(sp);
    lo.append(sp);
    lo.append(sp);
    lo.append(sp);
    assertTrue( lo.size() == 5 );
    lo.clear(true);
    assertTrue( lo.size() == 0 );
    lo.append(sp);
    lo.append(sp);
    lo.append(sp);
    lo.append(sp);
    lo.appendAndOwn(sp);
    assertTrue( lo.size() == 5 );
    lo.get(0);
    lo.get(1);
    lo.get(2);
    lo.get(3);
    lo.get(4);
    lo.clear(false);
    assertTrue( lo.size() == 0 );
    lo = null;
  }

  public void test_ListOf_create()
  {
    ListOf lo = new  ListOf();
    assertTrue( lo.getTypeCode() == libsbml.SBML_LIST_OF );
    assertTrue( lo.getNotes() == null );
    assertTrue( lo.getAnnotation() == null );
    assertTrue( lo.getMetaId().equals("") == true );
    assertTrue( lo.size() == 0 );
    lo = null;
  }

  public void test_ListOf_free_NULL()
  {
  }

  public void test_ListOf_remove()
  {
    ListOf lo = new  ListOf();
    SBase sp = new  Species(2,4);
    assertTrue( lo.size() == 0 );
    lo.append(sp);
    lo.append(sp);
    lo.append(sp);
    lo.append(sp);
    lo.append(sp);
    assertTrue( lo.size() == 5 );
    lo.remove(0);
    lo.remove(0);
    lo.remove(0);
    lo.remove(0);
    lo.remove(0);
    assertTrue( lo.size() == 0 );
    lo.append(sp);
    lo.append(sp);
    lo.append(sp);
    lo.append(sp);
    lo.appendAndOwn(sp);
    assertTrue( lo.size() == 5 );
    lo = null;
  }

  /**
   * Loads the SWIG-generated libSBML Java module when this class is
   * loaded, or reports a sensible diagnostic message about why it failed.
   */
  static
  {
    String varname;
    String shlibname;

    if (System.getProperty("mrj.version") != null)
    {
      varname = "DYLD_LIBRARY_PATH";    // We're on a Mac.
      shlibname = "libsbmlj.jnilib and/or libsbml.dylib";
    }
    else
    {
      varname = "LD_LIBRARY_PATH";      // We're not on a Mac.
      shlibname = "libsbmlj.so and/or libsbml.so";
    }

    try
    {
      System.loadLibrary("sbmlj");
      // For extra safety, check that the jar file is in the classpath.
      Class.forName("org.sbml.libsbml.libsbml");
    }
    catch (SecurityException e)
    {
      e.printStackTrace();
      System.err.println("Could not load the libSBML library files due to a"+
                         " security exception.\n");
      System.exit(1);
    }
    catch (UnsatisfiedLinkError e)
    {
      e.printStackTrace();
      System.err.println("Error: could not link with the libSBML library files."+
                         " It is likely\nyour " + varname +
                         " environment variable does not include the directories\n"+
                         "containing the " + shlibname + " library files.\n");
      System.exit(1);
    }
    catch (ClassNotFoundException e)
    {
      e.printStackTrace();
      System.err.println("Error: unable to load the file libsbmlj.jar."+
                         " It is likely\nyour -classpath option and CLASSPATH" +
                         " environment variable\n"+
                         "do not include the path to libsbmlj.jar.\n");
      System.exit(1);
    }
  }
}
